@@ -5,7 +5,11 @@ This module provides various tools that can be used within LangGraph agents.
 
 from .sandbox import PyodideSandboxTool, StatefulPyodideSandboxTool, create_sandbox_tool
 from .echo import EchoTool
-from .image_generation import ImageGenerationTool, create_image_generation_tool
+from .image_generation import (
+    ImageGenerationTool,
+    create_image_generation_tool,
+    ImageGenerationToolkit
+)
 
 __all__ = [
     "PyodideSandboxTool",
@@ -13,5 +17,6 @@ __all__ = [
     "create_sandbox_tool",
     "EchoTool",
     "ImageGenerationTool",
+    "ImageGenerationToolkit",
     "create_image_generation_tool"
-]
\ No newline at end of file
+]
