@@ -15,61 +15,12 @@ class McpServerTool(BaseTool):
     description: str
     args_schema: Optional[Type[BaseModel]] = None
     return_type: str = "str"
-    client: Any = Field(default=None, exclude=True)  # Exclude from serialization
+    client: Any
     server: str
     tool_timeout_sec: int = 60
 
     model_config = ConfigDict(arbitrary_types_allowed=True)
 
-    def __getstate__(self):
-        """Custom serialization to exclude non-serializable objects."""
-        state = self.__dict__.copy()
-        # Remove the client since it contains threading objects that can't be pickled
-        state['client'] = None
-        # Store args_schema as a schema dict instead of the dynamic class
-        if hasattr(self, 'args_schema') and self.args_schema is not None:
-            # Convert the Pydantic model back to schema dict for pickling
-            try:
-                state['_args_schema_dict'] = self.args_schema.model_json_schema()
-                state['args_schema'] = None
-            except Exception as e:
-                logger.warning(f"Failed to serialize args_schema: {e}")
-                # If conversion fails, just remove it
-                state['args_schema'] = None
-                state['_args_schema_dict'] = {}
-        return state
-
-    def __setstate__(self, state):
-        """Custom deserialization to handle missing objects."""
-        # Restore the args_schema from the stored schema dict
-        args_schema_dict = state.pop('_args_schema_dict', {})
-
-        # Initialize required Pydantic internal attributes
-        if '__pydantic_fields_set__' not in state:
-            state['__pydantic_fields_set__'] = set(state.keys())
-        if '__pydantic_extra__' not in state:
-            state['__pydantic_extra__'] = None
-        if '__pydantic_private__' not in state:
-            state['__pydantic_private__'] = None
-
-        # Directly update the object's __dict__ to bypass Pydantic validation
-        self.__dict__.update(state)
-
-        # Recreate the args_schema from the stored dict if available
-        if args_schema_dict:
-            try:
-                recreated_schema = self.create_pydantic_model_from_schema(args_schema_dict)
-                self.__dict__['args_schema'] = recreated_schema
-            except Exception as e:
-                logger.warning(f"Failed to recreate args_schema: {e}")
-                self.__dict__['args_schema'] = None
-        else:
-            self.__dict__['args_schema'] = None
-
-        # Note: client will be None after unpickling
-        # The toolkit should reinitialize the client when needed
-
-
     @staticmethod
     def create_pydantic_model_from_schema(schema: dict, model_name: str = "ArgsSchema"):
         def parse_type(field: dict, name: str = "Field") -> Any:
@@ -140,6 +91,7 @@ class McpServerTool(BaseTool):
         return create_model(model_name, **fields)
 
     def _run(self, *args, **kwargs):
+        # Extract the actual tool/prompt name (remove toolkit prefix)
         call_data = {
             "server": self.server,
             "tool_timeout_sec": self.tool_timeout_sec,
